@@ -182,10 +182,10 @@ def nlinfit(model, x, y, p0, alpha=0.05, **kwargs):
     return (pars, np.array(pint), np.array(SE))
 
 
-def correlation_coefficient(y, Y):
-    """Return R^2, correlation coefficient.
-    y is an array of observations.
-    Y is an array of predictions from a model.
+def Rsquared(y, Y):
+    """Return R^2, or coefficient of determination
+    y is a 1d array of observations.
+    Y is a 1d array of predictions from a model.
 
     Returns
     -------
